pub enum LocateError {
UnsupportedChannel {
browser: Browser,
channel: ReleaseChannel,
},
UnsupportedPlatform {
browser: Browser,
channel: ReleaseChannel,
platform: Platform,
},
NotFound {
browser: Browser,
channel: ReleaseChannel,
platform: Platform,
},
NoInstalledVariant {
browser: Browser,
strategy: &'static str,
platform: Platform,
},
}Expand description
Errors returned by browser discovery functions.
Variants
UnsupportedChannel
The requested channel is not modeled for the selected browser.
UnsupportedPlatform
The requested browser/channel combination is not supported on this platform.
Fields

channel: ReleaseChannelRequested release channel.
NotFound
No executable was found for a direct channel lookup.
Fields

channel: ReleaseChannelRequested release channel.
NoInstalledVariant
No executable was found while evaluating a fallback strategy.